package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$!`0````````````(``P`!````8)P$"#0```"PPP```````#0`(``(
M`"@`&P`:``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(1+,`
M`$2S```%`````!````$```#DO@``Y$X%".1.!0AT`@``S!(```8`````$```
M`@```/B^``#X3@4(^$X%"/@```#X````!@````0````$````2`$``$B!!`A(
M@00((````"`````$````!````%'E=&0```````````````````````````8`
M```$````4N5T9.2^``#D3@4(Y$X%"!P!```<`0``!`````$````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````/````
M80```',````+``````````````!#`````````$@```!'``````````````!:
M````/@```#D```!+````!````%@`````````,0```%\```!5````:@```&P`
M``!G````!0```"P``````````````"H```!C````1@``````````````9```
M`$D```!E````"0````````!2````<@````(```!-`````````!\`````````
M<`````````!1````;@``````````````9@```"@```!/````.@``````````
M````;P```#4```!`````10``````````````$P`````````_````````````
M```C`````````!P````P````#````#(````I````5```````````````6P``
M`%`````\````7@```$P````[````-``````````-````````````````````
M5@```&T`````````1````%T```!"````/0```"<````!````````````````
M`````````````````````````````````````````````````````````$X`
M``````````````````````````````\`````````$````!4```!@````````
M````````````%```````````````$@`````````9````````````````````
M`````%D`````````5P````````!H```````````````1````````````````
M````&P`````````F````:0```"0````(`````````"\````E````#@```!T`
M````````80```"$`````````&@````H``````````````$$`````````,P``
M`!X````N`````````'$```!<`````````$H````'``````````````!K````
M````````````````````````````````(@``````````````&``````````V
M`````````"L`````````````````````````%P`````````6`````````%,`
M````````!@```````````````````&(````W`````P```"`````M````.```
M`"4```!.````"`````@`````$!`$)4`$@*@1``&BAD&H0````DLH!"DXHC)'
MB@0,B$X```!0````````````````````4P```%4```!6`````````%<```!8
M`````````%D```!:````6P````````!<````````````````````70```&``
M`````````````&$```!C````9````&8`````````:````&L`````````;0``
M`&X```!O````<`````````#(U;)Q6>CM[.;_,*+.WD<MH^#[2>K3[PZGW:-K
M+\6;MMO-XYZ'^9R!:PE#U@TZEPO%B060#13BGB'_Y`ZR`8MOQ+F<0&M_FGQ_
MJ9R;;L7?']EQ6!R[XY)\U&34?*U+X\`R8MOMX:<""F:OS&9@%LE9>_!*:^)'
MQ@%#1=7L1^PS.GU!CL7#Y3\L\MO3'?JA;&"YC?$.````````````````````
M`/@"`````````````!(```!&`P`````````````2````L0``````````````
M$@```)0#`````````````!(```!_`P`````````````2````H0$`````````
M````$@```'H"`````````````!(````1```````````````@````(```````
M````````(````(4#`````````````!(```"-`0`````````````2````-`0`
M````````````$@```&X!`````````````!(```"``0`````````````2````
M7P,`````````````$@```"\#`````````````!(````)`P`````````````2
M````+`(`````````````$@```/T``````````````!(````<`@``````````
M```2````L`,`````````````$@```,H!`````````````!(````8!```````
M```````2````UP(`````````````$@```!$#`````````````!(```"8`@``
M```````````2````Z@$`````````````$@```*8!`````````````!(````U
M`@`````````````2````/@0`````````````$@````H$`````````````!(`
M```O`0`````````````2````RP,`````````````$@```#0`````````````
M`!(```#3`P`````````````2````70$`````````````$@```,@`````````
M`````!(```#X`P`````````````2````Q`,`````````````$@```/$#````
M`````````!(```"I`P`````````````2````>`,`````````````$@```/P$
M`````````````!(```!!`0`````````````2````X0,`````````````$@``
M`%P"`````````````!(```!6`P`````````````2````ZP(`````````````
M$@```$X"`````````````!(```"W`P`````````````2````D0(`````````
M````$@```*L!`````````````!(```!G`P`````````````2````O@,`````
M````````$@```*(#`````````````!(```#L```````````````2````0@``
M````````````$@```.@#`````````````!(````"!``````````````2````
MUP``````````````$@```/X!`````````````!(```"%`@`````````````2
M````4`$`````````````$@```(T#`````````````!(```!.`P``````````
M```2````\0(`````````````$@```!T!`````````````!(```!#`@``````
M```````2````5```````````````$@```)L#`````````````!(```#8`0``
M```````````2````8P``````````````$@```!$$`````````````!(```"/
M```````````````2````00,`````````````$@```'@``````````````!(`
M```+`0`````````````2````MP$``-R7!`@`````$@```)T$````V00(!```
M`!$`#P!F!0``X-L$"%U7```1``\`<`4``(G"!`CT!P``$@`-`)P%``!5IP0(
MT0$``!(`#0"7!```S-@$"``````2``X`+`0``&!1!0@$````(0`8`&\$```%
MHP0(#0```!(`#0`U!0``P-<$"%H````2``T`H````*R9!`@`````$@```"`%
M```\404(`````!``%P`B!0``/%$%"``````@`!<`*P0``&!1!0@$````(0`8
M`(T$``"PUP0(!0```!(`#0"/!0``$J,$"-$"```2``T`N@0``":I!`A8````
M$@`-`"H$``!@404(!````!$`&``E!```B=0$".`"```2``T`Z@0``&'`!`@W
M````$@`-``4%``#<RP0(8````!(`#0!>!```6%$%"``````0`/'_:@0``+!A
M!0@`````$`#Q_Z0$``#QS@0(+`4``!(`#0`@`P``!-D$"`0````1``\`)@4`
M`&"<!`@`````$@`-`,@$``#EH00((`$``!(`#0#>!```):8$"#`!```2``T`
M$04``%11!0@$````$0`7`&H"``"<F00(`````!(```"`!```XZ4$"$(````2
M``T`5P0``%A1!0@`````$`#Q_V$%``!0404(!````!$`%P!%!0``E<X$"%P`
M```2``T`+04``!2=!`A&````$@`-`*,"``!D404($P```!$`&`!]!0``5<$$
M"#0!```2``T`+P4``"R7!`@`````$@`+``!L:6)P97)L+G-O+C4N,3``7U]G
M;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M
M`%!E<FQ?27-T871B=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X:71?
M9FQA9W-?<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M<&-V
M7W!T<@!097)L7V%T9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`
M<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])<&%R
M<V5R7W!T<@!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?
M271O<%]E;G9?<'1R`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T<'9N
M`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?
M<'1R`%!E<FQ?26]P7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E
M90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P
M=@!097)L7T=T:')?:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?
M27!E<FQ?9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L
M7W)U;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!0
M97)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?
M<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L
M+G-O+C(`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P
M96-I9FEC`&-L;W-E`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`
M<F5A9`!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O
M<FL`97AI=`!S<')I;G1F`'-T<FYC;7``8VQO<V5D:7(`<W1R;F-P>0!?7W-T
M86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G971P
M:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!M
M96UC<'D`;W!E;F1I<@!?7V-T>7!E7V)?;&]C`&=E='5I9`!R96%D;&EN:P!E
M>&5C=G``<F5A9&1I<C8T`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]X<W1A=#8T`%]?;'AS=&%T-C0`;&EB
M8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`7V5N9`!P87)?8W5R<F5N
M=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?8W-U7V9I;FD`7V9P7VAW`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R96YT
M7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8VQE86YU<`!S:7IE7VQO861?;65?,@!?7V1A=&%?<W1A<G0`
M>'-?:6YI=`!?7VQI8F-?8W-U7VEN:70`6%-?26YT97)N86QS7U!!4E]#3$5!
M4E-404-+`&YA;65?;&]A9%]M95\R`'!A<E]M:W1M<&1I<@!P87)?<V5T=7!?
M;&EB<&%T:`!P87)?9FEN9'!R;V<`<&%R7VEN:71?96YV`$=,24)#7S(N-`!'
M3$E"0U\R+C,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXR`$=,24)#7S(N,``````"
M``,````#``,````````````#````!````````P`%``8``````````P````,`
M`@`"```````#````!``#`````P````<```````0``P`#``,``P`#`````P``
M``,``@````,``P````@``P`#```````#``,````````````#``,`!@``````
M```#```````#`````P`````````!``$``0`!``$``P`!``$````!``$``P`!
M``$``0`#``$``0`!``$``0`!``$``0`!``$``0````$``0`!``$``0````$`
M`0`!``4`%@,``!````!@````%&EI#0``"`"I!0``$````!-I:0T```<`LP4`
M`!````!R&6D)```%`+T%```0````$FEI#0``!`#)!0``$````!!I:0T```,`
MTP4````````!``(`QP(``!``````````$FEI#0``!@#)!0``$````!!I:0T`
M``(`TP4```````#P3P4(!@@``&!1!0@%7@``9%$%"`5P````4`4(!P$```10
M!0@'`@``"%`%"`<#```,4`4(!P0``!!0!0@'!0``%%`%"`<&```84`4(!P<`
M`!Q0!0@'3@``(%`%"`<(```D4`4(!PH``"A0!0@'"P``+%`%"`<,```P4`4(
M!PT``#10!0@'#@``.%`%"`</```\4`4(!Q```$!0!0@'$0``1%`%"`<2``!(
M4`4(!Q,``$Q0!0@'%```4%`%"`<5``!44`4(!Q8``%A0!0@'%P``7%`%"`<8
M``!@4`4(!QD``&10!0@'&@``:%`%"`<;``!L4`4(!QP``'!0!0@''0``=%`%
M"`<>``!X4`4(!Q\``'Q0!0@'(```@%`%"`<A``"$4`4(!R(``(A0!0@'(P``
MC%`%"`=J``"04`4(!U<``)10!0@')```F%`%"`<E``"<4`4(!R8``*!0!0@'
M)P``I%`%"`<H``"H4`4(!RD``*Q0!0@'*@``L%`%"`<K``"T4`4(!RP``+A0
M!0@'+0``O%`%"`<N``#`4`4(!R\``,10!0@',```R%`%"`<Q``#,4`4(!S(`
M`-!0!0@',P``U%`%"`<T``#84`4(!S4``-Q0!0@'-@``X%`%"`<W``#D4`4(
M!S@``.A0!0@'.0``[%`%"`<Z``#P4`4(!SL``/10!0@'/```^%`%"`<]``#\
M4`4(!SX```!1!0@'/P``!%$%"`=````(404(!T$```Q1!0@'0@``$%$%"`=#
M```4404(!T0``!A1!0@'10``'%$%"`=&```@404(!T<``"11!0@'2```*%$%
M"`=)```L404(!TH``#!1!0@'2P``-%$%"`=,```X404(!TT``%6)Y5.#[`3H
M`````%N!P[RX``"+D_S___^%TG0%Z)X```#HG04``.A(00``6%O)P_\U^$\%
M"/\E_$\%"`````#_)0!0!0AH`````.G@_____R4$4`4(:`@```#IT/____\E
M"%`%"&@0````Z<#_____)0Q0!0AH&````.FP_____R404`4(:"````#IH/__
M__\E%%`%"&@H````Z9#_____)1A0!0AH,````.F`_____R4<4`4(:#@```#I
M</____\E(%`%"&A`````Z6#_____)210!0AH2````.E0_____R4H4`4(:%``
M``#I0/____\E+%`%"&A8````Z3#_____)3!0!0AH8````.D@_____R4T4`4(
M:&@```#I$/____\E.%`%"&AP````Z0#_____)3Q0!0AH>````.GP_O___R5`
M4`4(:(````#IX/[___\E1%`%"&B(````Z=#^____)4A0!0AHD````.G`_O__
M_R5,4`4(:)@```#IL/[___\E4%`%"&B@````Z:#^____)510!0AHJ````.F0
M_O___R584`4(:+````#I@/[___\E7%`%"&BX````Z7#^____)6!0!0AHP```
M`.E@_O___R5D4`4(:,@```#I4/[___\E:%`%"&C0````Z4#^____)6Q0!0AH
MV````.DP_O___R5P4`4(:.````#I(/[___\E=%`%"&CH````Z1#^____)7A0
M!0AH\````.D`_O___R5\4`4(:/@```#I\/W___\E@%`%"&@``0``Z>#]____
M)810!0AH"`$``.G0_?___R6(4`4(:!`!``#IP/W___\EC%`%"&@8`0``Z;#]
M____)9!0!0AH(`$``.F@_?___R644`4(:"@!``#ID/W___\EF%`%"&@P`0``
MZ8#]____)9Q0!0AH.`$``.EP_?___R6@4`4(:$`!``#I8/W___\EI%`%"&A(
M`0``Z5#]____):A0!0AH4`$``.E`_?___R6L4`4(:%@!``#I,/W___\EL%`%
M"&A@`0``Z2#]____);10!0AH:`$``.D0_?___R6X4`4(:'`!``#I`/W___\E
MO%`%"&AX`0``Z?#\____)<!0!0AH@`$``.G@_/___R7$4`4(:(@!``#IT/S_
M__\ER%`%"&B0`0``Z<#\____)<Q0!0AHF`$``.FP_/___R704`4(:*`!``#I
MH/S___\EU%`%"&BH`0``Z9#\____)=A0!0AHL`$``.F`_/___R7<4`4(:+@!
M``#I</S___\EX%`%"&C``0``Z6#\____)>10!0AHR`$``.E0_/___R7H4`4(
M:-`!``#I0/S___\E[%`%"&C8`0``Z3#\____)?!0!0AHX`$``.D@_/___R7T
M4`4(:.@!``#I$/S___\E^%`%"&CP`0``Z0#\____)?Q0!0AH^`$``.GP^___
M_R4`404(:``"``#IX/O___\E!%$%"&@(`@``Z=#[____)0A1!0AH$`(``.G`
M^____R4,404(:!@"``#IL/O___\E$%$%"&@@`@``Z:#[____)111!0AH*`(`
M`.F0^____R48404(:#`"``#I@/O___\E'%$%"&@X`@``Z7#[____)2!1!0AH
M0`(``.E@^____R4D404(:$@"``#I4/O___\E*%$%"&A0`@``Z4#[____)2Q1
M!0AH6`(``.DP^____R4P404(:&`"``#I(/O___\E-%$%"&AH`@``Z1#[____
M)3A1!0AH<`(``.D`^___`````#'M7HGA@^3P4%12:+#7!`AHP-<$"%%6:(G4
M!`CH2_S___20D)"0D)"0D)"0D)"0D%6)Y5.#[`2`/7A1!0@`=4"+%7Q1!0BX
M\$X%""WL3@4(P?@"C5C_.=IS'XVV`````(U"`:-\404(_Q2%[$X%"(L5?%$%
M"#G:<N?&!7A1!0@!@\0$6UW#C78`C;PG`````%6)Y8/L"*'T3@4(A<!T$K@`
M````A<!T"<<$)/1.!0C_T,G#D%6)Y8/L*,=%_`C9!`C'!"0`````Z+_^__^+
M`(D$).BE^___B<*+1?R)1"0,QT0D")R9!`C'1"0$$MD$"(D4).AD_O__R<-5
MB>53@>PT$```BT4,B87H[___BT40B87D[___9:$4````B47X,<#'1"0(_P\`
M`(V%^.___XE$)`3'!"0NV00(Z'W]__^)A?3O__^#O?3O__\`?AR+A?3O__^#
MZ`$/MH0%^.___X3`=0>#K?3O__\!@[WT[___`'YDBX7T[___B40D",=$)`0O
M````C87X[___B00DZ(G]__^%P'1`BYWT[___QP0D`````.CC_?__BP")!"3H
MR?K__XG"B5PD#(V%^.___XE$)`B+A>CO__^)1"0$B10DZ`?\___K-,<$)```
M``#HJ?W__XL`B00DZ(_Z__^)PHN%Y.___XE$)`B+A>CO__^)1"0$B10DZ%'Z
M__^+1?AE,P44````=`7H4/S__X'$-!```%M=PU6)Y8/L*(-]"`!T":%@404(
MA<!U#,=%[`````#IH@```(M%"(E%].L$@T7T`8M5]`^V`H3`=`J+3?0/M@$\
M/77HBU7TBT4(B=$IP8E-\*%@404(B47XZU:+1?")1"0(BU4(B50D!(M-_(D,
M).B6_/__A<!U-8M%\`-%_`^V`#P]=2B+5?BA8%$%"(G1*<&)R,'X`HG"BT4,
MB1"+1?"#P`&+5?P!PHE5[.L9@T7X!(M-^(L)B4W\@WW\`'6<QT7L`````(M%
M[,G#58GE@^P8C47\B40D!(M%"(D$).@@____R<-5B>53@^PTBU4,#[8"/#UU
M!(-%#`&+30R)#"3HA?K__XE%^(U%](E$)`2+10B)!"3HZ?[__XE%X(-]X`!T
M0HM%X(D$).A<^O__.T7X#X($`0``BU4,#[8"BTW@B`&+5>`/M@*$P`^5P(-%
MX`&#10P!A,!UWL=%W`````#IJ`$``(L-8%$%"(E-Z,=%Y`````#K"(-%Z`2#
M1>0!BU7HBP*%P'7OH8!1!0B%P'0UBT7D@\`"P>`"BQ5@404(B40D!(D4).C.
M]___HV!1!0BA8%$%"(7`=6/'1=S_____Z4<!``#'!8!1!0@!````BT7D@\`"
MP>`"B00DZ$GZ__^)1>B#?>@`=0S'1=S_____Z1<!``"+1>3!X`*+%6!1!0B)
M1"0(B50D!(M-Z(D,).B5^O__BT7HHV!1!0B+%6!1!0B+1>2#P`'!X`*-!`+'
M``````"+1>2)1?2+50B)5>#K!(-%X`&+3>`/M@&$P'0*BU7@#[8"/#UUZ(L5
M8%$%"(M%],'@`HT<`HM5X(M%"(G1*<&)R`-%^(/``HD$).BF^?__B0.+`X7`
M=0G'1=S_____ZWB+%6!1!0B+1?3!X`*-!`*+`(E%X.L$@T7@`8M%"`^V`(M5
MX(@"BTW@#[8!A,`/E<"#10@!@_`!A,!U"HM5X`^V`CP]==&+3>#&`3V#1>`!
MBU4,#[8"BTW@B`&+5>`/M@*$P`^5P(-%X`&#10P!A,!UWL=%W`````"+1=R#
MQ#1;7<-5B>6#["CK+8L58%$%"(M%_,'@`@'"B57LBT7L@\`$BP"+5>R)`HM5
M[(L"A<!T!H-%[`3KY(U%_(E$)`2+10B)!"3HIOS__X7`=;W)PU6)Y8'L*"``
M`&6A%````(E%_#'`QX7TW___`````.B4]?__QT0D#$'9!`B)1"0(QT0D!$79
M!`B-A?OO__^)!"3H4O7__XF%\-___X.]\-___P!Y#\>%[-___P````#II```
M`,=$)`@`$```C87ZW___B40D!(V%^^___XD$).BT^/__B87PW___@[WPW___
M`'D,QX7LW___`````.MIBX7PW___@\`!B00DZ!CX__^)A?3?__^#O?3?__\`
M=0S'A>S?__\`````ZSV+A?#?__^)1"0(C87ZW___B40D!(N%]-___XD$).@;
M]___BX7PW___`X7TW___Q@``BY7TW___B97LW___BX7LW___BU7\93,5%```
M`'0%Z,GW___)PU6)Y8/L".C5_O__R<-5B>6![$@0``"+10B)A=SO__^+10R)
MA=CO__]EH10```")1?PQP,<$)%'9!`CH"?S__XF%[.___Z%$404(B40D!(N%
MW.___XD$).@[]___A<!T)XN%W.___XE$)`3'!"1:V00(Z.S[__^+E=SO__^)
ME=3O___I/@(``(N%W.___XD$).AR]O__B87T[___H4A1!0B)1"0$BX78[___
MB00DZ#7W__^)A?CO___IV0$``(N%^.___P^V`(3`=0K'A?CO__]GV00(@[WL
M[___`'0\BX7X[___B40D!(N%[.___XD$).@2^/__A<!U(*%(404(B40D!,<$
M)`````#HV?;__XF%^.___^E]`0``BX7X[___B00DZ.#U__^)A?#O___K%H.M
M\.___P&+A?#O__\#A?CO___&``"+A?#O__^#Z`$#A?CO__\/MA"A1%$%"`^V
M`#C"=,R+A?#O__^#P`$#A?3O__\]_P\``'XGBX7<[___B40D!,<$)%K9!`CH
MT_K__XN%W.___XF%U.___^DE`0``BQ5$404(BX7<[___B40D$(E4)`R+A?CO
M__^)1"0(QT0D!&G9!`B-A?SO__^)!"3HH_+__\<$)`````#H!_?__XL`B00D
MZ.WS__^)!"3H%?;__XE$)`2-A?SO__^)!"3H%S,``(7`=7/'!"0`````Z-/V
M__^+`(D$).BY\___B00DZ.'U__^+0!`E`/```#T`@```=4;'1"0$`0```(V%
M_.___XD$).C\\___A<!U+(V%_.___XE$)`3'!"1:V00(Z/WY__^-A?SO__^)
M!"3H9/;__XF%U.___^M*H4A1!0B)1"0$QP0D`````.A7]?__B87X[___@[WX
M[___``^%&O[__XN%W.___XE$)`3'!"1:V00(Z*GY__^+E=SO__^)E=3O__^+
MA=3O__^+5?QE,Q44````=`7HZ_3__\G#58GE@^P0BT4(B47\BT4(B47XZQ^+
M1?@/MA"A1%$%"`^V`#C"=0F+1?B#P`&)1?R#1?@!BT7X#[8`A,!UUXM%_,G#
M58GE@^P8@WT(`'0*BT4(#[8`A,!U%,<$)&?9!`CHE?7__XE%^.D!`0``BT4(
MB00DZ++S__^#Z`&+50@!PHE5_.L$@VW\`8M-_#M-"'89BU7\#[8"BQ5$404(
M#[82.-!TX>L$@VW\`8M-_#M-"'83BU7\#[8"BQ5$404(#[82.-!UX8M-_#M-
M"'4VBU7\#[8"BQ5$404(#[82.-!U$<<$)&?9!`CH#O7__XE%^.M]H411!0B)
M!"3H_/3__XE%^.MK@VW\`8M-_#M-"'83BU7\#[8"BQ5$404(#[82.-!TX8M5
M_(M%"(G1*<&)R(/``CT`$```=@G'1?@`````ZRV+5?R+10B)T2G!B<B#P`&)
M1"0(BT4(B40D!,<$)*!1!0CH`_'__\=%^*!1!0B+1?C)PU6)Y8/L2&6A%```
M`(E%_#'`H1S:!`B)1=JA(-H$"(E%WJ$DV@0(B47BH2C:!`B)1>:A+-H$"(E%
MZJ$PV@0(B47NH33:!`B)1?*A.-H$"(E%]@^W!3S:!`AFB47ZQP0D<-D$".C;
M^?__QP0D@-D$".C/^?__QP0D4=D$".C#^?__QP0DC-D$".BW^?__QP0DEMD$
M".BK^?__QP0DH-D$".B?^?__QP0D6MD$".B3^?__QP0DJMD$".B'^?__QP0D
ML]D$".A[^?__QP0DOMD$".@D]___B474@WW4`'03BT74B40D!,<$));9!`CH
M(O?__\<$),_9!`CH_/;__XE%U(-]U`!T$XM%U(E$)`3'!"3AV00(Z/KV___'
M!"3LV00(Z-3V__^)1=2#?=0`=!6+1=2)1"0$QP0D4=D$".C2]O__ZVC'!"3\
MV00(Z*KV__^)1=2#?=0`=!6+1=2)1"0$QP0DC-D$".BH]O__ZSZ-1=J#P!&)
M1=3'1"0("@```,=$)`0-V@0(BT74B00DZ*?R__^%P'46BT74@\`*B40D!,<$
M)(S9!`CH:/;__\=$)`08V@0(QP0D<-D$".A4]O__BT7\93,%%````'0%Z*CQ
M___)PU6)Y8/L&*%,404(@_C_=4''!"2,V00(Z`OV__^)1?R#??P`=!V+1?P/
MM@"$P'03BT7\#[8`/#!T"<=%[`$```#K!\=%[`````"+1>RC3%$%"*%,404(
MR<-5B>53@>QP`0``BT4(@\`<B47TQT7X`````.M$BT7TBP")1?"#1?0$BTWX
MBT7PB<+!XAB+1?#!X`@E``#_``G"BT7PP>@()0#_```)PHM%\,'H&`G0B82-
MF/[__X-%^`&#??@/?K;'1?@0````ZU^+3?B+1?B#Z`.+E(68_O__BT7X@^@(
MBX2%F/[__S'"BT7X@^@.BX2%F/[__S'"BT7X@^@0BX2%F/[__S'0B82-F/[_
M_XM5^(M%^(N$A9C^___!R!^)A)68_O__@T7X`8-]^$]^FXM%"(L`B47LBT4(
MBT`$B47HBT4(BT`(B47DBT4(BT`,B47@BT4(BT`0B47<C868_O__B478BT7L
MB<'!R1N+5>2+1>@APHM%Z/?0(T7@"="-!`&)P@-5W(M%V(L`C00"!9EY@EJ)
M1?"#1=@$P4WH`HM%\(G!P<D;BU7HBT7L(<*+1>SWT"-%Y`G0C00!B<(#5>"+
M1=B+`(T$`@69>8):B47<@T78!,%-[`*+1=R)P<')&XM5[(M%\"'"BT7P]]`C
M1>@)T(T$`8G"`U7DBT78BP"-!`(%F7F"6HE%X(-%V`3!3?`"BT7@B<'!R1N+
M5?"+1=PAPHM%W/?0(T7L"="-!`&)P@-5Z(M%V(L`C00"!9EY@EJ)1>2#1=@$
MP4W<`HM%Y(G!P<D;BU7<BT7@(<*+1>#WT"-%\`G0C00!B<(#5>R+1=B+`(T$
M`@69>8):B47H@T78!,%-X`*+1>B)P<')&XM5X(M%Y"'"BT7D]]`C1=P)T(T$
M`8G"`U7PBT78BP"-!`(%F7F"6HE%[(-%V`3!3>0"BT7LB<'!R1N+5>2+1>@A
MPHM%Z/?0(T7@"="-!`&)P@-5W(M%V(L`C00"!9EY@EJ)1?"#1=@$P4WH`HM%
M\(G!P<D;BU7HBT7L(<*+1>SWT"-%Y`G0C00!B<(#5>"+1=B+`(T$`@69>8):
MB47<@T78!,%-[`*+1=R)P<')&XM5[(M%\"'"BT7P]]`C1>@)T(T$`8G"`U7D
MBT78BP"-!`(%F7F"6HE%X(-%V`3!3?`"BT7@B<'!R1N+5?"+1=PAPHM%W/?0
M(T7L"="-!`&)P@-5Z(M%V(L`C00"!9EY@EJ)1>2#1=@$P4W<`HM%Y(G!P<D;
MBU7<BT7@(<*+1>#WT"-%\`G0C00!B<(#5>R+1=B+`(T$`@69>8):B47H@T78
M!,%-X`*+1>B)P<')&XM5X(M%Y"'"BT7D]]`C1=P)T(T$`8G"`U7PBT78BP"-
M!`(%F7F"6HE%[(-%V`3!3>0"BT7LB<'!R1N+5>2+1>@APHM%Z/?0(T7@"="-
M!`&)P@-5W(M%V(L`C00"!9EY@EJ)1?"#1=@$P4WH`HM%\(G!P<D;BU7HBT7L
M(<*+1>SWT"-%Y`G0C00!B<(#5>"+1=B+`(T$`@69>8):B47<@T78!,%-[`*+
M1=R)P<')&XM5[(M%\"'"BT7P]]`C1>@)T(T$`8G"`U7DBT78BP"-!`(%F7F"
M6HE%X(-%V`3!3?`"BT7@B<'!R1N+5?"+1=PAPHM%W/?0(T7L"="-!`&)P@-5
MZ(M%V(L`C00"!9EY@EJ)1>2#1=@$P4W<`HM%Y(G!P<D;BU7<BT7@(<*+1>#W
MT"-%\`G0C00!B<(#5>R+1=B+`(T$`@69>8):B47H@T78!,%-X`*+1>B)P<')
M&XM5X(M%Y"'"BT7D]]`C1=P)T(T$`8G"`U7PBT78BP"-!`(%F7F"6HE%[(-%
MV`3!3>0"BT7LB<'!R1N+5>2+1>@APHM%Z/?0(T7@"="-!`&)P@-5W(M%V(L`
MC00"!9EY@EJ)1?"#1=@$P4WH`HM%\(G!P<D;BU7HBT7L(<*+1>SWT"-%Y`G0
MC00!B<(#5>"+1=B+`(T$`@69>8):B47<@T78!,%-[`*+1=R)P<')&XM5[(M%
M\#'0,T7HC00!B<(#5>2+1=B+`(T$`@6AZ]ENB47@@T78!,%-\`*+1>")P<')
M&XM5\(M%W#'0,T7LC00!B<(#5>B+1=B+`(T$`@6AZ]ENB47D@T78!,%-W`*+
M1>2)P<')&XM5W(M%X#'0,T7PC00!B<(#5>R+1=B+`(T$`@6AZ]ENB47H@T78
M!,%-X`*+1>B)P<')&XM5X(M%Y#'0,T7<C00!B<(#5?"+1=B+`(T$`@6AZ]EN
MB47L@T78!,%-Y`*+1>R)P<')&XM5Y(M%Z#'0,T7@C00!B<(#5=R+1=B+`(T$
M`@6AZ]ENB47P@T78!,%-Z`*+1?")P<')&XM5Z(M%[#'0,T7DC00!B<(#5>"+
M1=B+`(T$`@6AZ]ENB47<@T78!,%-[`*+1=R)P<')&XM5[(M%\#'0,T7HC00!
MB<(#5>2+1=B+`(T$`@6AZ]ENB47@@T78!,%-\`*+1>")P<')&XM5\(M%W#'0
M,T7LC00!B<(#5>B+1=B+`(T$`@6AZ]ENB47D@T78!,%-W`*+1>2)P<')&XM5
MW(M%X#'0,T7PC00!B<(#5>R+1=B+`(T$`@6AZ]ENB47H@T78!,%-X`*+1>B)
MP<')&XM5X(M%Y#'0,T7<C00!B<(#5?"+1=B+`(T$`@6AZ]ENB47L@T78!,%-
MY`*+1>R)P<')&XM5Y(M%Z#'0,T7@C00!B<(#5=R+1=B+`(T$`@6AZ]ENB47P
M@T78!,%-Z`*+1?")P<')&XM5Z(M%[#'0,T7DC00!B<(#5>"+1=B+`(T$`@6A
MZ]ENB47<@T78!,%-[`*+1=R)P<')&XM5[(M%\#'0,T7HC00!B<(#5>2+1=B+
M`(T$`@6AZ]ENB47@@T78!,%-\`*+1>")P<')&XM5\(M%W#'0,T7LC00!B<(#
M5>B+1=B+`(T$`@6AZ]ENB47D@T78!,%-W`*+1>2)P<')&XM5W(M%X#'0,T7P
MC00!B<(#5>R+1=B+`(T$`@6AZ]ENB47H@T78!,%-X`*+1>B)P<')&XM5X(M%
MY#'0,T7<C00!B<(#5?"+1=B+`(T$`@6AZ]ENB47L@T78!,%-Y`*+1>R)P<')
M&XM5Y(M%Z#'0,T7@C00!B<(#5=R+1=B+`(T$`@6AZ]ENB47P@T78!,%-Z`*+
M1?")P<')&XM5Z(M%[#'0,T7DC00!B<(#5>"+1=B+`(T$`@6AZ]ENB47<@T78
M!,%-[`*+1=R)P<')&XM5[(M%\#'0,T7HC00!B<(#5>2+1=B+`(T$`@6AZ]EN
MB47@@T78!,%-\`*+1>")P<')&XM5\(M%W#'0,T7LC00!B<(#5>B+1=B+`(T$
M`@6AZ]ENB47D@T78!,%-W`*+1>2)P\'+&XM5\(M%W`G0B<$C3>"+5?"+1=PA
MT`G(C00#B<(#5>R+1=B+`(T$`BTD0^1PB47H@T78!,%-X`*+1>B)P\'+&XM5
MW(M%X`G0B<$C3>2+5=R+1>`AT`G(C00#B<(#5?"+1=B+`(T$`BTD0^1PB47L
M@T78!,%-Y`*+1>R)P\'+&XM5X(M%Y`G0B<$C3>B+5>"+1>0AT`G(C00#B<(#
M5=R+1=B+`(T$`BTD0^1PB47P@T78!,%-Z`*+1?")P\'+&XM5Y(M%Z`G0B<$C
M3>R+5>2+1>@AT`G(C00#B<(#5>"+1=B+`(T$`BTD0^1PB47<@T78!,%-[`*+
M1=R)P\'+&XM5Z(M%[`G0B<$C3?"+5>B+1>PAT`G(C00#B<(#5>2+1=B+`(T$
M`BTD0^1PB47@@T78!,%-\`*+1>")P\'+&XM5[(M%\`G0B<$C3=R+5>R+1?`A
MT`G(C00#B<(#5>B+1=B+`(T$`BTD0^1PB47D@T78!,%-W`*+1>2)P\'+&XM5
M\(M%W`G0B<$C3>"+5?"+1=PAT`G(C00#B<(#5>R+1=B+`(T$`BTD0^1PB47H
M@T78!,%-X`*+1>B)P\'+&XM5W(M%X`G0B<$C3>2+5=R+1>`AT`G(C00#B<(#
M5?"+1=B+`(T$`BTD0^1PB47L@T78!,%-Y`*+1>R)P\'+&XM5X(M%Y`G0B<$C
M3>B+5>"+1>0AT`G(C00#B<(#5=R+1=B+`(T$`BTD0^1PB47P@T78!,%-Z`*+
M1?")P\'+&XM5Y(M%Z`G0B<$C3>R+5>2+1>@AT`G(C00#B<(#5>"+1=B+`(T$
M`BTD0^1PB47<@T78!,%-[`*+1=R)P\'+&XM5Z(M%[`G0B<$C3?"+5>B+1>PA
MT`G(C00#B<(#5>2+1=B+`(T$`BTD0^1PB47@@T78!,%-\`*+1>")P\'+&XM5
M[(M%\`G0B<$C3=R+5>R+1?`AT`G(C00#B<(#5>B+1=B+`(T$`BTD0^1PB47D
M@T78!,%-W`*+1>2)P\'+&XM5\(M%W`G0B<$C3>"+5?"+1=PAT`G(C00#B<(#
M5>R+1=B+`(T$`BTD0^1PB47H@T78!,%-X`*+1>B)P\'+&XM5W(M%X`G0B<$C
M3>2+5=R+1>`AT`G(C00#B<(#5?"+1=B+`(T$`BTD0^1PB47L@T78!,%-Y`*+
M1>R)P\'+&XM5X(M%Y`G0B<$C3>B+5>"+1>0AT`G(C00#B<(#5=R+1=B+`(T$
M`BTD0^1PB47P@T78!,%-Z`*+1?")P\'+&XM5Y(M%Z`G0B<$C3>R+5>2+1>@A
MT`G(C00#B<(#5>"+1=B+`(T$`BTD0^1PB47<@T78!,%-[`*+1=R)P\'+&XM5
MZ(M%[`G0B<$C3?"+5>B+1>PAT`G(C00#B<(#5>2+1=B+`(T$`BTD0^1PB47@
M@T78!,%-\`*+1>")P\'+&XM5[(M%\`G0B<$C3=R+5>R+1?`AT`G(C00#B<(#
M5>B+1=B+`(T$`BTD0^1PB47D@T78!,%-W`*+1>2)P\'+&XM5\(M%W`G0B<$C
M3>"+5?"+1=PAT`G(C00#B<(#5>R+1=B+`(T$`BTD0^1PB47H@T78!,%-X`*+
M1>B)P\'+&XM5W(M%X`G0B<$C3>2+5=R+1>`AT`G(C00#B<(#5?"+1=B+`(T$
M`BTD0^1PB47L@T78!,%-Y`*+1>R)P<')&XM5Y(M%Z#'0,T7@C00!B<(#5=R+
M1=B+`(T$`BTJ/ITUB47P@T78!,%-Z`*+1?")P<')&XM5Z(M%[#'0,T7DC00!
MB<(#5>"+1=B+`(T$`BTJ/ITUB47<@T78!,%-[`*+1=R)P<')&XM5[(M%\#'0
M,T7HC00!B<(#5>2+1=B+`(T$`BTJ/ITUB47@@T78!,%-\`*+1>")P<')&XM5
M\(M%W#'0,T7LC00!B<(#5>B+1=B+`(T$`BTJ/ITUB47D@T78!,%-W`*+1>2)
MP<')&XM5W(M%X#'0,T7PC00!B<(#5>R+1=B+`(T$`BTJ/ITUB47H@T78!,%-
MX`*+1>B)P<')&XM5X(M%Y#'0,T7<C00!B<(#5?"+1=B+`(T$`BTJ/ITUB47L
M@T78!,%-Y`*+1>R)P<')&XM5Y(M%Z#'0,T7@C00!B<(#5=R+1=B+`(T$`BTJ
M/ITUB47P@T78!,%-Z`*+1?")P<')&XM5Z(M%[#'0,T7DC00!B<(#5>"+1=B+
M`(T$`BTJ/ITUB47<@T78!,%-[`*+1=R)P<')&XM5[(M%\#'0,T7HC00!B<(#
M5>2+1=B+`(T$`BTJ/ITUB47@@T78!,%-\`*+1>")P<')&XM5\(M%W#'0,T7L
MC00!B<(#5>B+1=B+`(T$`BTJ/ITUB47D@T78!,%-W`*+1>2)P<')&XM5W(M%
MX#'0,T7PC00!B<(#5>R+1=B+`(T$`BTJ/ITUB47H@T78!,%-X`*+1>B)P<')
M&XM5X(M%Y#'0,T7<C00!B<(#5?"+1=B+`(T$`BTJ/ITUB47L@T78!,%-Y`*+
M1>R)P<')&XM5Y(M%Z#'0,T7@C00!B<(#5=R+1=B+`(T$`BTJ/ITUB47P@T78
M!,%-Z`*+1?")P<')&XM5Z(M%[#'0,T7DC00!B<(#5>"+1=B+`(T$`BTJ/ITU
MB47<@T78!,%-[`*+1=R)P<')&XM5[(M%\#'0,T7HC00!B<(#5>2+1=B+`(T$
M`BTJ/ITUB47@@T78!,%-\`*+1>")P<')&XM5\(M%W#'0,T7LC00!B<(#5>B+
M1=B+`(T$`BTJ/ITUB47D@T78!,%-W`*+1>2)P<')&XM5W(M%X#'0,T7PC00!
MB<(#5>R+1=B+`(T$`BTJ/ITUB47H@T78!,%-X`*+1>B)P<')&XM5X(M%Y#'0
M,T7<C00!B<(#5?"+1=B+`(T$`BTJ/ITUB47L@T78!,%-Y`*+1>R)P<')&XM5
MY(M%Z#'0,T7@C00!B<(#5=R+1=B+`(T$`BTJ/ITUB47P@T78!,%-Z`*+1?")
MP<')&XM5Z(M%[#'0,T7DC00!B<(#5>"+1=B+`(T$`BTJ/ITUB47<@T78!,%-
M[`*+10B+`(G"`U7<BT4(B1"+10B+0`2)P@-5\(M%"(E0!(M%"(M`"(G"`U7L
MBT4(B5`(BT4(BT`,B<(#5>B+10B)4`R+10B+0!")P@-5Y(M%"(E0$('$<`$`
M`%M=PU6)Y8M%",<``2-%9XM%",=`!(FKS>^+10C'0`C^W+J8BT4(QT`,=E0R
M$(M%",=`$/#ATL.+10C'0!0`````BT4(QT`8`````(M%",=`7`````!=PU6)
MY8/L*(M%"(M0%(M%$,'@`XT$`HE%^(M%"(M`%#M%^'8/BT4(BT`8C5`!BT4(
MB5`8BU4(BT7XB4(4BT4(BU`8BT40P>@=`<*+10B)4!B+10B+0%R%P`^$IP``
M`(M%"(M07+A`````*=")1?R+1?P[11!^!HM%$(E%_(M-_(M%"(U0'(M%"(M`
M7`'"B4PD"(M%#(E$)`2)%"3HJMS__XM%_"E%$(M%_`%%#(M%"(M`7(G"`U7\
MBT4(B5!<BT4(BT!<@_A`=6B+10B)!"3H">S__^LPBT4(C5`<QT0D"$````"+
M10R)1"0$B10DZ%C<__^#10Q`@VT00(M%"(D$).C7Z___@WT0/W_*BU40BT4(
MC4@<B50D"(M%#(E$)`2)#"3H(]S__XM5"(M%$(E"7,G#58GE@^P$BT4,B00D
MZ)GK__^+10R+`,'H&(G"BT4(B!"+10B-4`&+10R+`,'H$(@"BT4(C5`"BT4,
MBP#!Z`B(`HM%"(U0`XM%#(L`B`*+10B-4`2+10R+0`3!Z!B(`HM%"(U0!8M%
M#(M`!,'H$(@"BT4(C5`&BT4,BT`$P>@(B`*+10B-4`>+10R+0`2(`HM%"(U0
M"(M%#(M`",'H&(@"BT4(C5`)BT4,BT`(P>@0B`*+10B-4`J+10R+0`C!Z`B(
M`HM%"(U0"XM%#(M`"(@"BT4(C5`,BT4,BT`,P>@8B`*+10B-4`V+10R+0`S!
MZ!"(`HM%"(U0#HM%#(M`#,'H"(@"BT4(C5`/BT4,BT`,B`*+10B-4!"+10R+
M0!#!Z!B(`HM%"(U0$8M%#(M`$,'H$(@"BT4(C5`2BT4,BT`0P>@(B`*+10B-
M4!.+10R+0!"(`LG#58GE@^PHBT4,BT`4B47XBT4,BT`8B47TBT7XP>@#@^`_
MB47\BT4,C5`<BT7\C00"Q@"`@T7\`8-]_#A^5;A`````*T7\B<&+10R-4!R+
M1?R-!`*)3"0(QT0D!`````")!"3H'MG__XM%#(D$).CEZ?__BT4,@\`<QT0D
M"#@```#'1"0$`````(D$).CUV/__ZRJX.````"M%_(G!BT4,C5`<BT7\C00"
MB4PD",=$)`0`````B00DZ,G8__^+1?3!Z!B)PHM%#(A05(M%],'H$(G"BT4,
MB%!5BT7TP>@(B<*+10R(4%:+1?2)PHM%#(A05XM%^,'H&(G"BT4,B%!8BT7X
MP>@0B<*+10R(4%F+1?C!Z`B)PHM%#(A06HM%^(G"BT4,B%!;BT4,B40D!(M%
M"(D$).AU_?__R<-5B>6#[!C'1?P`````QT7X`````.C2V?__B00DZ*K9__^)
M1?B#??@`=`B+1?B+`(E%_(M%_,G#58GE@^P8QP0D`````.A"V___BP")!"3H
M*-C__XD$).A0VO__B40D!(M%"(D$).B5%P``A<!U>L<$)`````#H$=O__XL`
MB00DZ/?7__^)!"3H']K__XM`$"4`\```/0!```!T+<<$)`````#HY-K__XL`
MB00DZ,K7__^)!"3H\MG__XM`$"4`\```/0"@``!U(,=$)`0"````BT4(B00D
MZ!#8__^%P'4)QT7\`0```.L'QT7\`````(M%_,G#58GE4X/L1,=%^`````#'
M1?0`````QT74/MH$",=%V$[:!`C'1=Q6V@0(QT7@8]H$",=%Y&C:!`C'1>AZ
MV@0(QT7L`````,=%\`````#IQ````(M%^(D$).B;W?__B47T@WWT`'0*BT7T
M#[8`A,!U%XM%"(E$)`2+1?B)!"3HD-W__^F+````BT4(B40D!(M%](D$).BN
MV/__A<!U=8M%"(D$).@/V/__B<.A2%$%"(D$).@`V/__`<.+1?2)!"3H\]?_
M_XT$`X/``HD$).B%V/__B47LBQ5(404(BT7TB40D$(E4)`R+10B)1"0(QT0D
M!&G9!`B+1>R)!"3H)]7__XM%[(E$)`2+1?B)!"3H`-W__X-%\`&+1?"+1(74
MB47XBT7X#[8`A,`/A23___^#Q$1;7<-5B>564X'L0($``(M%"(F%U'[__V6A
M%````(E%]#'`QX5(?___`````,>%1'___P````#'A4!___\`````QX7X?O__
M>]H$",>%_'[__X/:!`C'A0!___]GV00(QX4$?___>MH$",>%X'[__^'9!`C'
MA>1^__^(V@0(QX7H?O__C]H$",>%['[__Y?:!`C'A?!^__^<V@0(QX7T?O__
M>MH$",>%"'___Z#:!`C'A0Q___^EV@0(QX40?___>MH$",>%/'___Z[:!`C'
MA3A___]ZV@0(QX4T?___`````,>%,'___P````#'A2Q___\`````QX4<?___
M`````,<$)%'9!`CHO=O__XF%0'___X.]0'___P!T-(N%0'___P^V`(3`=">+
MA4!___^)!"3HF_W__XN%0'___XD$).@4V/__B870?O__Z8D&``#HB?S__XF%
M,'___X.],'___P!U;<>%4'___P````#K.(N%1'___XD$).A,V___B85`?___
M@[U`?___`'04BX5`?___B00DZ+[7__^)A3!___^#A5!___\!@[TP?___`'4@
MBX50?___BX2%"'___XF%1'___XN%1'___P^V`(3`=9^#O3!___\`=0S'A3!_
M__^SV@0(ZU"+A3!___^)A4Q____K->@0U?__BQ"+A4Q___\/M@`/OL`!P(T$
M`@^W``^WP(/@"(7`=0F+A4Q____&`%^#A4Q___\!BX5,?___#[8`A,!UOL>%
M4'___P````#K2HN%1'___XD$).AZVO__B85`?___@[U`?___`'0FBX5`?___
MB00DZ*C[__^%P'04BX5`?___B00DZ-K6__^)A4A___^#A5!___\!@[U(?___
M`'4@BX50?___BX2%X'[__XF%1'___XN%1'___P^V`(3`=8W'A5!___\`````
MZRV+A4!___^)!"3H1OO__X7`=!2+A4!___^)!"3H>-;__XF%2'___X.%4'__
M_P&#O4A___\`=2"+A5!___^+A(7X?O__B85`?___BX5`?___#[8`A,!UJHN%
M2'___XD$).ADU/__B<.+A3Q___^)!"3H5-3__P'#BX4P?___B00DZ$34__\!
MPXN%.'___XD$).@TU/__C00#!0`$``")A1Q___^+A1Q___^)!"3HN-3__XF%
M+'___XL51%$%"(N%,'___XE$)!2+A3Q___^)1"00B50D#(N%2'___XE$)`C'
M1"0$NMH$"(N%+'___XD$).A$T?__QT0D!.T!``"+A2Q___^)!"3H7M'__\<$
M)&/:!`CH\]C__XF%0'___XN%0'___XD$).ANU?__B<*+A=1^__^+`(E4)`2)
M!"3HCMS__XF%-'___X.]-'___P!U#HN%U'[__XL`B84T?___Z(#B__^%P`^%
M<P(``,=$)`0`````BX4T?___B00DZ-C4__^)A2A___^#O2A___\`#X1*`@``
MQT0D#`(```#'1"0$[O___\=$)`C_____BX4H?___B00DZ&_1___'1"0(!@``
M`(V%5'___XE$)`2+A2A___^)!"3HS]'__P^VA51___^$P`^%V@````^VA55_
M__\\0P^%RP````^VA59___\\00^%O`````^VA5=___\\0P^%K0````^VA5A_
M__\\2`^%G@````^VA5E___\\10^%CP```,=$)`P"````QT0D!,;____'1"0(
M_____XN%*'___XD$).C/T/__QT0D""D```"-A51___^)1"0$BX4H?___B00D
MZ"_1__^+'411!0B+A2Q___^)!"3H.]+__XG"`Y4L?___BX4X?___B40D$(V%
M5'___XE$)`R)7"0(QT0D!,/:!`B)%"3H>\___^DF`@``C854____B00DZ#OT
M___K(HN%)'___XE$)`B-A51___^)1"0$C854____B00DZ&OT___'1"0(`(``
M`(V%5'___XE$)`2+A2A___^)!"3HE-#__XF%)'___X.])'___P!_KXN%*'__
M_XD$).@'TO__C854____B40D!(U%X(D$).B=]O__QX4@?___`````.LXBX4@
M?___#[9$!>`/MLB+A2!___\!P(G"C46W`=")3"0(QT0D!-#:!`B)!"3HM<[_
M_X.%('___P&#O2!___\3?K_&1=\`BQU$404(BX4L?___B00DZ!W1__^)P@.5
M+'___XN%.'___XE$)!"-1;>)1"0,B5PD",=$)`3#V@0(B10DZ&#.___I"P$`
M`,>%&'___P````"+A2Q___^)!"3HT]#__XF%%'___\=$)`08V@0(QP0DC-D$
M".@4UO__Z$3.__^)PXLU1%$%"(N%+'___XD$).B>T/__B<(#E2Q___^+A3A_
M__^)1"00B5PD#(ET)`C'1"0$U=H$"(D4).CDS?__ZV>+E11___^+A2Q___\!
MT,8``(.%&'___P'HY<W__XG#BS5$404(BX4L?___B00DZ#_0__^)P@.5+'__
M_XN%.'___XE$)!2+A1A___^)1"00B5PD#(ET)`C'1"0$X=H$"(D4).A[S?__
MQT0D!.T!``"+A2Q___^)!"3HE<W__X/X_W40Z$O-__^+`(/X$0^$;O___XN%
M+'___XE$)`3'!"11V00(Z"75__^+A2Q___^)!"3H!??__XN5+'___XF5T'[_
M_XN%T'[__XM5]&4S%10```!T!>A9T/__@<1`@0``6UY=PU6)Y5.![(0```#'
M1?``````@WT(``^$.P$``(M%"`^V`(3`#X0M`0``BT4(B00DZ+O.__^)1?B#
M??@`#X05`0``Z>(```"+1?2#P!/'1"0$9]D$"(D$).@ST?__A<`/A,0```"+
M1?2#P!/'1"0$\-H$"(D$).@5T?__A<`/A*8```"+10B)!"3H`L___XG#BT7T
M@\`3B00DZ/+.__^-!`.#P`*)1>R+1>R)!"3H?L___XE%\(M%](/`$XE$)`R+
M10B)1"0(QT0D!//:!`B+1?")!"3H)\S__XU%C(E$)`2+1?")!"3HN0P``(/X
M_W0<BT6<)0#P```]`$```'4-BT7PB00DZ/?^___K"XM%\(D$).B)SO__BT7P
MB00DZ'[-___'1?``````BT7XB00DZ"S.__^)1?2#??0`#X4&____BT7XB00D
MZ*3.__^+10B)!"3H"<___X'$A````%M=PU6)Y8/L&(M%"(D$).@XVO__B47\
MBT7\B00DZ.C9__^)1?CH(]W__X7`=#.#?0@`="V+10@/M@"$P'0CQT0D!*[:
M!`B+1?B)!"3H<L[__SM%^'4+BT4(B00DZ$/^___)PU6)Y5.#[!3'!"0`````
MZ)W/__^+`(D$).B#S/__B00DZ"O+__^+`(M8!,<$)`````#H>L___XL`B00D
MZ&#,__^)!"3HJ,O__P^V`(A#&,<$)`````#H5L___XL`B00DZ#S,__^)!"3H
MY,K__XL`BU@$QP0D`````.@SS___BP")!"3H&<S__XD$).AQR___BP`/MT`0
M9B7_`6:)0QK'!"0`````Z`?/__^+`(D$).CMR___B00DZ)7*__^+`(M8!,<$
M)`````#HY,[__XL`B00DZ,K+___'1"0(`````,=$)`1ZV@0(B00DZ$+.__^)
M0QS'!"0`````Z+/.__^+`(D$).B9R___B00DZ$'*__^+`(M8!,<$)`````#H
MD,[__XL`B00DZ';+__^)!"3HGLK__XL`B4,@QP0D`````.AMSO__BP")!"3H
M4\O__XD$).C[R?__BP"+0`2)1?3'!"0`````Z$?.__^+`(D$).@MR___B00D
MZ$7-__^+`(7`="C'!"0`````Z"/.__^+`(D$).@)R___B00DZ"'-__^+`(M`
M;(E%^.L'QT7X`````(M5^(M%](E0),<$)`````#HZ\W__XL`B00DZ-'*__^)
M!"3H><G__XL`BT`$QT`H`````,<$)`````#HP<W__XL`B00DZ*?*__^)!"3H
M3\G__XL`BT`$QT`L`````,<$)`````#HE\W__XL`B00DZ'W*__^)!"3H)<G_
M_XL`BU@$QP0D`````.ATS?__BP")!"3H6LK__XD$).@BS?__BP")0S"#Q!1;
M7<-5B>6#[!C'!"0`````Z$7-__^+`(D$).@KRO__QT0D!/____^)!"3H:\K_
M_\<$)`````#H'\W__XL`B00DZ`7*___'1"0(`````,=$)`0\S`0(B00DZ$W-
M___)PU6)Y593@^Q`QT7@`````,<$)`````#HX,S__XL`B00DZ,;)__^)!"3H
M/LK__\8``<<$)'#9!`CH(-#__XE%W(-]W`!T%XM%W`^V`#PQ=0V+1=R#P`$/
MM@"$P'0%Z`/8___'!"0`````Z([,__^+`(D$).ATR?__QT0D#`L```#'1"0(
M`0```,=$)`3YV@0(B00DZ!3)__^)1?2#??0`#X0^`0``BT7TBT`,BT`8B47P
MQT7D`0```.G*````BT7DC5C_QP0D`````.@MS/__BP")!"3H$\G__XG"QT0D
M#`````")7"0(BT7PB40D!(D4).AVRO__B47L@WWL``^$D@```(M%[(L`BT`(
M)0`$``"%P'0-BT7LBP"+0`R)1<CK.HM%[(L8QP0D`````.C*R___BP")!"3H
ML,C__\=$)`P"````QT0D"`````")7"0$B00DZ`3,__^)1<B+%:QA!0B+1>3!
MX`*-!`*+`(M5R(E4)`2)!"3HH<O__X7`=1:#1>`!@T7D`:&H804(.47D#XPH
M____H:AA!0B#Z`$[1>!U0<=%Y`$```#K+L<$)`````#H1<O__XL`B00DZ"O(
M__^)PHM%\(E$)`2)%"3HRL?__XE%Z(-%Y`&AJ&$%"#E%Y'S(QP0D`````.@-
MR___BP")!"3H\\?__\=$)`P%````QT0D"`$```#'1"0$_MH$"(D$).B3Q___
MB47T@WWT`'1PBT7TBT`,BQC'!"0`````Z,;*__^+`(D$).BLQ___QT0D"`#;
M!`B)7"0$B00DZ'C'__^+1?2+0`R+`(M`""4``$``A<!T*HM%](M`#(L8QP0D
M`````.B`RO__BP")!"3H9L?__XE<)`2)!"3H.LG__\<$)`````#H7LK__XL`
MB00DZ$3'___'1"0,!0```,=$)`@!````QT0D!`7;!`B)!"3HY,;__XE%](-]
M]``/A(8```#'1=@`````QP0D6MD$".AUS?__B478@WW8`'0UBT7TBT`,BQC'
M!"0`````Z/?)__^+`(D$).C=QO__B<*+1=B)1"0(B5PD!(D4).BHQO__ZS6A
MK&$%"(LPBT7TBT`,BQC'!"0`````Z+O)__^+`(D$).BAQO__B70D"(E<)`2)
M!"3H#\O__\<$)`````#HE<G__XL`B00DZ'O&__^)!"3H\\;__\8``,<$)```
M``#H=,G__XL`B00DZ%K&__^)!"3HDLG__\<``````,<$)%'9!`CHL<S__Z.D
M804(H:1A!0B%P`^%%@$``*&L804(B00DZ,[O__^CI&$%"*&L804(B47,BT7T
MBT`,BP"+0`@E``0``(7`=!"+1?2+0`R+`(M`#(E%T.L]BT7TBT`,BQC'!"0`
M````Z.S(__^+`(D$).C2Q?__QT0D#`(```#'1"0(`````(E<)`2)!"3H)LG_
M_XE%T(M5S(E4)`2+1=")!"3HP<;__XE%Y(M%](M`#(L`BT`()0`$``"%P'00
MBT7TBT`,BP"+0`R)1=3K/8M%](M`#(L8QP0D`````.AVR/__BP")!"3H7,7_
M_\=$)`P"````QT0D"`````")7"0$B00DZ+#(__^)1=2AK&$%"(L0BT7DB40D
M#(M%U(E$)`B)5"0$QP0D"-L$".AXQ___H:1A!0C'1"0$[0$``(D$).C3P___
MB47D@WWD`'0T@WWD$70N@WWD_W0HBQ6D804(H:QA!0B+"(M%Y(E$)`R)5"0(
MB4PD!,<$)#C;!`CH)L?__X/$0%M>7<-5B>6#[!C'!"0`````Z+W'__^+`(D$
M).BCQ/__B00DZ-/(___'!"0`````Z)_'__^+`(D$).B%Q/__QT0D%`````#'
M1"00>MH$",=$)`QZV@0(QT0D"/'.!`C'1"0$AML$"(D$).@UQ?__R<.-3"0$
M@^3P_W'\58GE48/L-(E-Z(M%Z(/`"(E$)`B+1>B#P`2)1"0$BT7HB00DZ!#'
M___'1"0(W)<$",=$)`3<EP0(QP0DK)D$".B8`@``QP0D`````.@HQ/__#[8`
MA,!U3>@,Q/__HZ!A!0BAH&$%"(7`=0S'!"0!````Z"+'__^AH&$%"(D$).BU
MQ/__QP0D`````.C)QO__BP")!"3HK\/__XD$).@7QO__Q@``QP0D`````.BH
MQO__BP")!"3HCL/__XD$).BFQO__B<(/M@*#R`*(`L<$)`````#H@,;__XL`
MB00DZ&;#__^)!"3H?L;__XG"#[8"@\@!B`*+5>B+`H/`!;H`````4E#?+"2-
M9"0(V>[>P=T%J-L$"-G)VNG?X)X/E\"#\`&$P'4,QP0D9%$%".AWQ?__BU7H
MBP*#P`7!X`*)!"3HA,7__Z.L804(BQ6L804(BTWHBT$$BP")`J&L804(@\`$
MQP";VP0(H:QA!0B#P`C'`.#;!`C'!:AA!0@#````BQ6L804(H:AA!0C!X`*-
M!`+'`)[;!`BAJ&$%"(/``:.H804(QT7T`0```.LUBPVL804(H:AA!0@#1?2)
MPK@!````*=#!X`+WV`'!BT7HBU`$BT7TP>`"C00"BP")`8-%]`&+5>B+`CE%
M]'S!BPVL804(BT7HBQ"AJ&$%"(T$`HG"N`$````IT,'@`O?8C00!QP``````
MBPVL804(BT7HBQ"AJ&$%"(T$`H/H`8L5H&$%",=$)!``````B4PD#(E$)`C'
M1"0$'=0$"(D4).CGP/__B47X@WWX`'40H:!A!0B)!"3H@<'__XE%^*&@804(
MB00DZ('#___'!"2`V00(Z#;(__^%P'4PH:1A!0B%P'41QP0D4=D$".@=R/__
MHZ1A!0BAI&$%"(7`=`VAI&$%"(D$).B1]/__H:!A!0B)!"3H9,#__^@?PO__
MBT7X@\0T65V-8?S#D)"0D)"0D%6)Y5/H,@```('#>W@``(/L$(N#3`$``(E$
M)`R+11")1"0(BT4,B40D!(M%"(D$).BWP/__@\006UW#BQPDPY!5B>5=PXUT
M)@"-O"<`````58GE5U93Z.#___^!PREX``"#[`SH4[___XV[\/[__XV#\/[_
M_RG'P?\"A?]T)#'VBT40B40D"(M%#(E$)`2+10B)!"3_E+/P_O__@\8!.?YR
MWH/$#%M>7UW#D)"0D)"058GE4X/L#(M%#.A\____@</%=P``QP0D`P```(E$
M)`B+10B)1"0$Z-"___^#Q`Q;7<.0D)"0D)"0D)"0D)"0D%6)Y5.#[`R+10SH
M//___X'#A7<``,<$)`,```")1"0(BT4(B40D!.BPP/__@\0,6UW#D)"0D)"0
MD)"0D)"0D)!5B>53@^P$H>1.!0B#^/]T$[OD3@4(9I"#ZP3_T(L#@_C_=?2#
MQ`1;7<.0D%6)Y5.#[`3H`````%N!PQQW``#HK,/__UE;R<,`````````````
M```````````````````#`````0`"`'!E<FQX<VDN8P!$>6YA3&]A9&5R.CIB
M;V]T7T1Y;F%,;V%D97(`+W!R;V,O<V5L9B]E>&4`+P`Z`&5X90`O<')O8R\E
M:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`+@`E<R5S)7,`4$%27TE.251)
M04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!
M0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,3T)!3%]$14)51P!005)?
M1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?
M1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0```%]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@``!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)2
M05)97U!!5$@`4$%42`!$64Q$7TQ)0E)!4EE?4$%42```0SI<5$5-4``O=&UP
M`%1-4$1)4@!414U01$E2`%1%35``5$U0`%5315(`55-%4DY!344`<&%R+0!3
M65-414T`)7,E<R5S)7,`)7-C86-H92TE<R5S`"4P,G@`)7-T96UP+25U)7,`
M)7-T96UP+25U+25U)7,`+BX`)7,O)7,`05)'5@`8`'!E<FP`,```)7,Z(&5X
M96-U=&EO;B!O9B`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@=&5M<&]R87)Y('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`26YT97)N86QS.CI005(Z
M.D)/3U0`+64`+2T`````````````@/___\]!`````````````````````'!A
M<BYP;```````````````````````````````````(R$O=7-R+V)I;B]P97)L
M"@IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C
M:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S
M92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC
M=#L*"B-L:6YE(#$U.0H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I
M<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@
M("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M
M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z
M.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D
M<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R
M96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@
M;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@
M("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@
M("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E
M;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@
M:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@
M<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H
M870@87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@
M("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R
M(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A
M;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S
M('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@
M=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@
M("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2
M(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@
M("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@
M,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R
M7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@
M("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@
M("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M
M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@
M("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@
M("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F
M;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I
M.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A
M;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%2
M1U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA
M<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M
M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@
M9F]R("AK97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@
M+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051(
M"FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>
M35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@
M/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@
M("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@
M.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D[
M"@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD
M;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI[
M"B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H
M96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*
M("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN
M;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#([
M"B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@
M97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R
M96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH
M(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D
M871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X
M=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E
M<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@
M("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@
M)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA
M;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\
M7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H
M)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN
M+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E
M;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@
M("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@
M('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70[
M"B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@
M?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A
M;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S
M:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@
M)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@
M("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@
M("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$[
M"B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT
M("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]
M"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U
M;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L
M"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@
M(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*
M("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@
M("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO
M9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R
M("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E
M<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K
M97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@
M>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\[
M"B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@
M9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*
M"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z
M.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D
M9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*
M("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U
M<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE
M+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@
M("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U
M="`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U
M=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG
M+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A
M7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE
M9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P
M<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!0
M05(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E
M<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*
M("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY
M("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*
M("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D
M7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C
M(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@
M("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@
M("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C
M=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@
M("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C
M=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@
M("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC
M($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O
M=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*)'%U:65T(#T@
M,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PH*(R!$;VXG="!S=V%L;&]W(&%R
M9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A
M<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@
M<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A
M;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@
M<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("!M
M>2!`861D7W1O7VEN8SL*("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("1!
M4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0[
M"@H@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@<'5S:"!`
M861D7W1O7VEN8RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E
M<2`G32<I('L*("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("!]
M"B`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("!U;G-H
M:69T($!P87)?87)G<RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D
M,2!E<2`G3R<I('L*("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("1B=6YD
M;&4@/2`G<VET92<["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G
M0B<I('L*("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("1Q=6EE
M="`](#$["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*
M("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8
M.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("!]"B`@("`@("`@96QS
M:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R
M.PH@("`@("`@('T*"B`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("!I
M9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@9&5L
M971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@(&EN:71?:6YC*"D[
M"B`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`F
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@
M("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@
M("`@("`@97AI=#L*("`@("`@("!]"B`@("!]"@H@("`@=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U
M<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[
M>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@
M<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII
M<#L*("`@('T*"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY
M("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N
M(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G
M.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F
M:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@
M(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@
M;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@
M/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D
M;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@
M<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U
M="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@
M("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@
M)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD[
M"B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@
M/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H
M)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@
M("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&
M:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@
M("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@
M("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N
M9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A
M;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O
M<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D
M=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L
M("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D
M<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L
M;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@
M)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@
M("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@
M("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M
M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E
M(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@<F5Q=6ER95]M
M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@
M("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"![
M"B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@
M("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@
M("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@
M("`@?2!`24Y#.PH*("`@("`@("!I9B`H)$-O;F9I9WM?9&5L:6U](&5Q("=<
M7"<I('L@<WM<7'U[+WUG(&9O<B!`:6YC('T*"B`@("`@("`@;7D@)69I;&5S
M.PH@("`@("`@("]>7SPH+BLI)"\@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y
M<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*
M"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL
M92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@
M("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@
M("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO
M:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D
M<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D
M,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D
M("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@
M(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@
M("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@
M("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I
M9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X[
M"B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@
M("`@("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC:R!U<"!A=71O
M+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y.R\*("`@
M("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H(EA33&]A9&5R
M+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I
M='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)
M3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F
M*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@
M("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@
M("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H
M92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S
M=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M
M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@
M('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^
M;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S
M=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@
M("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@
M(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2![
M"B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D
M9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?
M;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]
M"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M
M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN
M="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W
M-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E
M<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O
M9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T
M(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@
M("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@
M("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/
M(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@
M("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D
M(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*
M("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*
M("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I
M/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@
M)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@
M("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S
M*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@
M("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]
M"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO
M=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50
M871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y
M;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T
M<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,[
M"B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R
M=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M
M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D
M97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L
M93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S
M.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E
M(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2
M.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@
M("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I
M;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@
M(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PI]"@HC
M(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O
M;6MT;7!D:7(N8PIS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@
M("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@
M("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@
M("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE
M>'0@=6YL97-S("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@
M("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@
M("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH
M)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@
M("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@
M("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@
M('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@
M("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S
M97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D
M<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK
M9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%
M04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@
M("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@
M("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*
M("`@("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@
M("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@
M(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@
M("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O
M<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y
M"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P
M<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@
M("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@
M)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT
M+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D
M9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M
M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE
M.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I
M;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F
M:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I
M.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*<W5B(%]S971?<')O
M9VYA;64@>PH@("`@:68@*"1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM0
M05)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]
M("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%
M3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%
M35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I
M.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@
M:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@
M("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@
M(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G
M;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1
M)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N
M97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6
M>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI
M;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@
M("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@
M7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K
M('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D
M.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H
M*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@
M8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>
M*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L
M:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*
M"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!
M3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@
M>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@
M("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!2
M3T=.04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[
M)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]4
M14U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]
M"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@
M;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS
M=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F
M:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E
M;'-E('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET
M7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E
M<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@
M("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E
M>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*
M?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C
M:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E
M;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I
M<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G
M;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I
M9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T52
M4D]2.PH*,3L*"B-L:6YE(#DY,PH*7U]%3D1?7PH`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````/__
M__\`````_____P```````````0````$````!````L@(```$```"]`@```0``
M`,<"```!````%@,```$```!)!```#````"R7!`@-````S-@$"`0```!H@00(
M]?[_;\"$!`@%````2(T$"`8````8A@0("@```-T%```+````$````!4`````
M`````P```/1/!0@"````>`(``!0````1````%P```+24!`@1````G)0$"!(`
M```8````$P````@```#^__]O#)0$"/___V\"````\/__;R:3!`@`````````
M````````````````````````````````````````````````````````````
M^$X%"```````````<I<$"(*7!`B2EP0(HI<$"+*7!`C"EP0(TI<$".*7!`CR
MEP0(`I@$"!*8!`@BF`0(,I@$"$*8!`A2F`0(8I@$"'*8!`B"F`0(DI@$"**8
M!`BRF`0(PI@$"-*8!`CBF`0(\I@$"`*9!`@2F00((ID$"#*9!`A"F00(4ID$
M"&*9!`ARF00(@ID$")*9!`BBF00(LID$",*9!`C2F00(XID$"/*9!`@"F@0(
M$IH$""*:!`@RF@0(0IH$"%*:!`ABF@0(<IH$"(*:!`B2F@0(HIH$"+*:!`C"
MF@0(TIH$".*:!`CRF@0(`IL$"!*;!`@BFP0(,IL$"$*;!`A2FP0(8IL$"'*;
M!`B"FP0(DIL$"**;!`BRFP0(PIL$"-*;!`CBFP0(\IL$"`*<!`@2G`0((IP$
M"#*<!`A"G`0(4IP$"```````````/=D$"#_9!`C_____P-L$"%Q7````1T-#
M.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U
M(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U
M8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T
M+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#
M.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U
M(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U
M8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T
M+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#
M.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``+G-H<W1R=&%B`"YI
M;G1E<G``+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R
M`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N8W1O<G,`
M+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S
M`"YC;VUM96YT````````````````````````````````````````````````
M````````"P````$````"````-($$"#0!```3```````````````!````````
M`!,````'`````@```$B!!`A(`0``(```````````````!``````````E````
M!0````(```!H@00(:`$``%@#```%``````````0````$````(0```/;__V\"
M````P(0$",`$``!8`0``!0`````````$````!````"L````+`````@```!B&
M!`@8!@``,`<```8````!````!````!`````S`````P````(```!(C00(2`T`
M`-T%``````````````$`````````.P```/___V\"````)I,$""83``#F````
M!0`````````"`````@```$@```#^__]O`@````R4!`@,%```D`````8````"
M````!`````````!7````"0````(```"<E`0(G!0``!@````%``````````0`
M```(````8`````D````"````M)0$"+04``!X`@``!0````P````$````"```
M`&D````!````!@```"R7!`@L%P``,```````````````!`````````!D````
M`0````8```!<EP0(7!<````%``````````````0````$````;P````$````&
M````8)P$"&`<``!L/``````````````0`````````'4````!````!@```,S8
M!`C,6```'```````````````!`````````![`````0````(`````V00(`%D`
M`#U:`````````````"``````````@P````$````"````0#,%"$"S```$````
M```````````$`````````(T````!`````P```.1.!0CDO@``"```````````
M````!`````````"4`````0````,```#L3@4([+X```@```````````````0`
M````````FP````$````#````]$X%"/2^```$```````````````$````````
M`*`````&`````P```/A.!0CXO@``^`````8`````````!`````@```"I````
M`0````,```#P3P4(\+\```0```````````````0````$````K@````$````#
M````]$\%"/2_``!(`0`````````````$````!````+<````!`````P```#Q1
M!0@\P0``'```````````````!`````````"]````"`````,```!@404(6,$`
M`%`0`````````````"``````````P@````$``````````````%C!``",`0``
M```````````!``````````$````#``````````````#DP@``RP``````````
+`````0``````````
